@@ -5,20 +5,20 @@ use pathfinding::{matrix, matrix::Matrix, utils::absdiff};
 #[test]
 fn sm() {
     let mut m = Matrix::new(2, 2, 0usize);
-    m[&(0, 0)] = 0;
-    m[&(0, 1)] = 1;
-    m[&(1, 0)] = 10;
-    m[&(1, 1)] = 11;
-    m[&(0, 1)] = 2;
-    assert_eq!(m[&(0, 0)], 0);
-    assert_eq!(m[&(0, 1)], 2);
-    assert_eq!(m[&(1, 0)], 10);
-    assert_eq!(m[&(1, 1)], 11);
+    m[(0, 0)] = 0;
+    m[(0, 1)] = 1;
+    m[(1, 0)] = 10;
+    m[(1, 1)] = 11;
+    m[(0, 1)] = 2;
+    assert_eq!(m[(0, 0)], 0);
+    assert_eq!(m[(0, 1)], 2);
+    assert_eq!(m[(1, 0)], 10);
+    assert_eq!(m[(1, 1)], 11);
     m.fill(33);
-    assert_eq!(m[&(0, 0)], 33);
-    assert_eq!(m[&(0, 1)], 33);
-    assert_eq!(m[&(1, 0)], 33);
-    assert_eq!(m[&(1, 1)], 33);
+    assert_eq!(m[(0, 0)], 33);
+    assert_eq!(m[(0, 1)], 33);
+    assert_eq!(m[(1, 0)], 33);
+    assert_eq!(m[(1, 1)], 33);
 }
 
 #[test]
@@ -27,12 +27,12 @@ fn from_vec() {
     assert_eq!(m.rows, 2);
     assert_eq!(m.columns, 3);
     assert!(!m.is_square());
-    assert_eq!(m[&(0, 0)], 10);
-    assert_eq!(m[&(0, 1)], 20);
-    assert_eq!(m[&(0, 2)], 30);
-    assert_eq!(m[&(1, 0)], 40);
-    assert_eq!(m[&(1, 1)], 50);
-    assert_eq!(m[&(1, 2)], 60);
+    assert_eq!(m[(0, 0)], 10);
+    assert_eq!(m[(0, 1)], 20);
+    assert_eq!(m[(0, 2)], 30);
+    assert_eq!(m[(1, 0)], 40);
+    assert_eq!(m[(1, 1)], 50);
+    assert_eq!(m[(1, 2)], 60);
 }
 
 #[test]
@@ -43,10 +43,10 @@ fn from_vec_error() {
 #[test]
 fn to_vec() {
     let mut m = Matrix::new(2, 2, 0usize);
-    m[&(0, 0)] = 0;
-    m[&(0, 1)] = 1;
-    m[&(1, 0)] = 10;
-    m[&(1, 1)] = 11;
+    m[(0, 0)] = 0;
+    m[(0, 1)] = 1;
+    m[(1, 0)] = 10;
+    m[(1, 1)] = 11;
     assert_eq!(m.to_vec(), vec![0, 1, 10, 11]);
 }
 
@@ -56,10 +56,10 @@ fn square_from_vec() {
     assert_eq!(m.rows, 2);
     assert_eq!(m.columns, 2);
     assert!(m.is_square());
-    assert_eq!(m[&(0, 0)], 10);
-    assert_eq!(m[&(0, 1)], 20);
-    assert_eq!(m[&(1, 0)], 30);
-    assert_eq!(m[&(1, 1)], 40);
+    assert_eq!(m[(0, 0)], 10);
+    assert_eq!(m[(0, 1)], 20);
+    assert_eq!(m[(1, 0)], 30);
+    assert_eq!(m[(1, 1)], 40);
 }
 
 #[test]
@@ -255,7 +255,7 @@ fn empty_extend() {
     let mut i = 0;
     for row in 0..m.rows {
         for column in 0..m.columns {
-            assert_eq!(m[&(row, column)], i);
+            assert_eq!(m[(row, column)], i);
             i += 1;
         }
     }
@@ -276,7 +276,7 @@ fn matrix_macro() {
     let mut i = 0;
     for row in 0..m.rows {
         for column in 0..m.columns {
-            assert_eq!(m[&(row, column)], i);
+            assert_eq!(m[(row, column)], i);
             i += 1;
         }
     }
